==> mediawiki-1.26.2-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesPfl.php <==
<?php
/** Pälzisch (Pälzisch)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Als-Holder
 * @author Imbericle
 * @author M-sch
 * @author Manuae
 * @author SPS
 * @author Xqt
 */

$fallback = 'de';

$namespaceNames = array(
	NS_MEDIA            => 'Medium',
	NS_SPECIAL          => 'Schbezial',
	NS_TALK             => 'Babble',
	NS_USER             => 'Middawaida',
	NS_USER_TALK        => 'Middawaida_Dischbediere',
	NS_PROJECT_TALK     => '$1_Dischbediere',
	NS_FILE             => 'Dadai',
	NS_FILE_TALK        => 'Dadai_Dischbediere',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_Dischbediere',
	NS_TEMPLATE         => 'Vorlach',
	NS_TEMPLATE_TALK    => 'Vorlach_Dischbediere',
	NS_HELP             => 'Hilf',
	NS_HELP_TALK        => 'Hilf_Dischbediere',
	NS_CATEGORY         => 'Sachgrubb',
	NS_CATEGORY_TALK    => 'Sachgrubb_Dischbediere',
);

$namespaceAliases = array(
	# German namespaces
	'Medium'                 => NS_MEDIA,
	'Spezial'                => NS_SPECIAL,
	'Diskussion'             => NS_TALK,
	'Benutzer'               => NS_USER,
	'Benutzer_Diskussion'    => NS_USER_TALK,
	'Benudzer'               => NS_USER,
	'Benudzer_Dischbediere'  => NS_USER_TALK,
	'$1_Diskussion'          => NS_PROJECT_TALK,
	'Datei'                  => NS_FILE,
	'Datei_Diskussion'       => NS_FILE_TALK,
	'MediaWiki_Diskussion'   => NS_MEDIAWIKI_TALK,
	'Vorlage'                => NS_TEMPLATE,
	'Vorlage_Diskussion'     => NS_TEMPLATE_TALK,
	'Hilfe'                  => NS_HELP,
	'Hilfe_Diskussion'       => NS_HELP_TALK,
	'Kategorie'              => NS_CATEGORY,
	'Kategorie_Diskussion'   => NS_CATEGORY_TALK,
	'Kadegorie'              => NS_CATEGORY,
	'Kadegorie_Dischbediere' => NS_CATEGORY_TALK,
);

// Remove German aliases
$namespaceGenderAliases = array();

==> mediawiki-1.28.1-1-any.pkg.tar.xz: usr/share/webapps/mediawiki/languages/messages/MessagesPfl.php <==
<?php
/** Pälzisch (Pälzisch)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Als-Holder
 * @author Imbericle
 * @author M-sch
 * @author Manuae
 * @author SPS
 * @author Xqt
 */

$fallback = 'de';

$namespaceNames = [
	NS_MEDIA            => 'Medium',
	NS_SPECIAL          => 'Schbezial',
	NS_TALK             => 'Babble',
	NS_USER             => 'Middawaida',
	NS_USER_TALK        => 'Middawaida_Dischbediere',
	NS_PROJECT_TALK     => '$1_Dischbediere',
	NS_FILE             => 'Dadai',
	NS_FILE_TALK        => 'Dadai_Dischbediere',
	NS_MEDIAWIKI        => 'MediaWiki',
	NS_MEDIAWIKI_TALK   => 'MediaWiki_Dischbediere',
	NS_TEMPLATE         => 'Vorlach',
	NS_TEMPLATE_TALK    => 'Vorlach_Dischbediere',
	NS_HELP             => 'Hilf',
	NS_HELP_TALK        => 'Hilf_Dischbediere',
	NS_CATEGORY         => 'Sachgrubb',
	NS_CATEGORY_TALK    => 'Sachgrubb_Dischbediere',
];

$namespaceAliases = [
	# German namespaces
	'Medium'                 => NS_MEDIA,
	'Spezial'                => NS_SPECIAL,
	'Diskussion'             => NS_TALK,
	'Benutzer'               => NS_USER,
	'Benutzer_Diskussion'    => NS_USER_TALK,
	'Benudzer'               => NS_USER,
	'Benudzer_Dischbediere'  => NS_USER_TALK,
	'$1_Diskussion'          => NS_PROJECT_TALK,
	'Datei'                  => NS_FILE,
	'Datei_Diskussion'       => NS_FILE_TALK,
	'MediaWiki_Diskussion'   => NS_MEDIAWIKI_TALK,
	'Vorlage'                => NS_TEMPLATE,
	'Vorlage_Diskussion'     => NS_TEMPLATE_TALK,
	'Hilfe'                  => NS_HELP,
	'Hilfe_Diskussion'       => NS_HELP_TALK,
	'Kategorie'              => NS_CATEGORY,
	'Kategorie_Diskussion'   => NS_CATEGORY_TALK,
	'Kadegorie'              => NS_CATEGORY,
	'Kadegorie_Dischbediere' => NS_CATEGORY_TALK,
];

// Remove German aliases
$namespaceGenderAliases = [];
